@@ -16,12 +16,14 @@ import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.function.Predicate;
+import java.util.logging.Level;
 import java.util.logging.Logger;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import uk.ac.starlink.table.formats.AsciiTableBuilder;
 import uk.ac.starlink.table.formats.CsvTableBuilder;
 import uk.ac.starlink.table.formats.IpacTableBuilder;
+import uk.ac.starlink.table.formats.MrtTableBuilder;
 import uk.ac.starlink.table.formats.TstTableBuilder;
 import uk.ac.starlink.table.formats.WDCTableBuilder;
 import uk.ac.starlink.table.jdbc.JDBCHandler;
@@ -90,6 +92,12 @@ import uk.ac.starlink.util.URLDataSource;
  *      (format name="cdf")
  * <li> {@link uk.ac.starlink.ecsv.EcsvTableBuilder}
  *      (format name="ecsv")
+ * <li> {@link uk.ac.starlink.pds4.Pds4TableBuilder}
+ *      (format name="pds4")
+ * <li> {@link uk.ac.starlink.table.formats.MrtTableBuilder}
+ *      (format name="mrt")
+ * <li> {@link uk.ac.starlink.parquet.ParquetTableBuilder}
+ *      (format name="parquet")
  * <li> {@link uk.ac.starlink.feather.FeatherTableBuilder}
  *      (format name="feather")
  * </ul>
@@ -190,6 +198,9 @@ public class StarTableFactory {
         "uk.ac.starlink.votable.VOTableBuilder",
         "uk.ac.starlink.cdf.CdfTableBuilder",
         "uk.ac.starlink.ecsv.EcsvTableBuilder",
+        "uk.ac.starlink.pds4.Pds4TableBuilder",
+        "uk.ac.starlink.table.formats.MrtTableBuilder",
+        "uk.ac.starlink.parquet.ParquetTableBuilder",
         "uk.ac.starlink.feather.FeatherTableBuilder",
         "uk.ac.starlink.gbin.GbinTableBuilder",
     };
@@ -202,6 +213,7 @@ public class StarTableFactory {
     };
     private static TableScheme[] dfltSchemes = {
         new LoopTableScheme(),
+        new TestTableScheme(),
         new ClassTableScheme(),
     };
 
@@ -235,10 +247,11 @@ public class StarTableFactory {
                 logger.config( className + " registered" );
             }
             catch ( ClassNotFoundException e ) {
-                logger.config( className + " not found - can't register" );
+                logger.info( className + " not found - can't register" );
             }
-            catch ( Exception e ) {
-                logger.config( "Failed to register " + className + " - " + e );
+            catch ( Throwable e ) {
+                logger.log( Level.WARNING, "Failed to register " + className,
+                            e );
             }
         }
 
@@ -1370,6 +1383,7 @@ public class StarTableFactory {
         catch ( TableFormatException e ) {
             String msg = new StringBuffer()
                 .append( "Bad format for " )
+                .append( ":" )
                 .append( schemeName )
                 .append( ":" )
                 .append( scheme.getSchemeUsage() )
@@ -1386,7 +1400,7 @@ public class StarTableFactory {
      * Parses a scheme-format table specification as a scheme name
      * and a scheme-specific part.
      * Normally schemes are of the form
-     * ":&lt;scheme-name&gt;:&lt;scheme-specific-part>gt;",
+     * ":&lt;scheme-name&gt;:&lt;scheme-specific-part&gt;",
      * but as a special case the initial colon may be omitted for JDBC
      * (backward compatibility).
      *
@@ -1395,7 +1409,7 @@ public class StarTableFactory {
      *           a 2-element array giving [scheme-name,scheme-specific-part];
      *           otherwise null
      */
-    private static String[] parseSchemeLocation( String location ) {
+    public static String[] parseSchemeLocation( String location ) {
         if ( location.startsWith( "jdbc:" ) ) {
             return new String[] { "jdbc", location.substring( 5 ) };
         }
