@@ -18,6 +18,7 @@ import java.util.Iterator;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.logging.Level;
 import java.util.logging.Logger;
 import uk.ac.starlink.table.jdbc.JDBCHandler;
 import uk.ac.starlink.table.jdbc.WriteMode;
@@ -47,6 +48,7 @@ import uk.ac.starlink.util.Loader;
  * <li> {@link uk.ac.starlink.fits.HealpixFitsTableWriter}
  * <li> {@link uk.ac.starlink.votable.VOTableWriter}
  * <li> {@link uk.ac.starlink.ecsv.EcsvTableWriter}
+ * <li> {@link uk.ac.starlink.parquet.ParquetTableWriter}
  * <li> {@link uk.ac.starlink.feather.FeatherTableWriter}
  * <li> {@link uk.ac.starlink.table.formats.TextTableWriter}
  * <li> {@link uk.ac.starlink.table.formats.AsciiTableWriter}
@@ -80,6 +82,7 @@ public class StarTableOutput {
         "uk.ac.starlink.fits.ColFitsTableWriter",
         "uk.ac.starlink.votable.VOTableWriter",
         "uk.ac.starlink.ecsv.EcsvTableWriter",
+        "uk.ac.starlink.parquet.ParquetTableWriter",
         "uk.ac.starlink.feather.FeatherTableWriter",
         TextTableWriter.class.getName(),
         AsciiTableWriter.class.getName(),
@@ -128,10 +131,11 @@ public class StarTableOutput {
                                " registered" );
             }
             catch ( ClassNotFoundException e ) {
-                logger.config( className + " not found - can't register" );
+                logger.info( className + " not found - can't register" );
             }
-            catch ( Exception e ) {
-                logger.config( "Failed to register " + className + " - " + e );
+            catch ( Throwable e ) {
+                logger.log( Level.WARNING, "Failed to register " + className,
+                            e );
             }
         }
 
@@ -140,9 +144,7 @@ public class StarTableOutput {
                                                     StarTableWriter.class ) );
 
         /* Further initialization. */
-        voWriter_ =
-            getTransferableWriter( handlers_
-                                  .toArray( new StarTableWriter[ 0 ] ) );
+        voWriter_ = createTransferableWriter();
     }
 
     /**
@@ -668,30 +670,24 @@ public class StarTableOutput {
 
     /**
      * Sets up one serializer suitable for streaming objects during
-     * drag and drop.  In the current implementation a VOTable BINARY
-     * is used if available, otherwise VOTable TABLEDATA.
+     * drag and drop.  In the current implementation a VOTable BINARY2
+     * serialization is used if available, otherwise VOTable TABLEDATA.
      *
      * @param  handlers  available handler list
      * @return  widely-understandable serializer
      */
-    private static StarTableWriter
-            getTransferableWriter( StarTableWriter[] handlers ) {
-
-        /* Identify a suitable handler by name.  Can't easily do it by class,
-         * since the VOTable classes are probably not available at
-         * compile time. */
-        StarTableWriter tdWriter = null;
-        for ( int ih = 0; ih < handlers.length; ih++ ) {
-            StarTableWriter handler = handlers[ ih ];
-            String formatName = handler.getFormatName();
-            if ( "votable-binary-inline".equals( formatName ) ) {
-                return handler;
+    private final StarTableWriter createTransferableWriter() {
+        for ( String fname :
+              new String[] { "votable(format=BINARY2)", "votable" } ) {
+            try {
+                return getHandler( fname );
             }
-            if ( "votable-tabledata".equals( formatName ) ) {
-                tdWriter = handler;
+            catch ( TableFormatException e ) {
+                logger.warning( "No format " + fname + " for transferables" );
             }
         }
-        return tdWriter;
+        logger.warning( "No table drag'n'drop available" );
+        return null;
     }
 
     /**
