@@ -1,5 +1,6 @@
 package uk.ac.starlink.table;
 
+import java.util.List;
 import java.util.Map;
 
 /**
@@ -57,6 +58,18 @@ public interface ValueInfo {
      */
     String getUtype();
 
+    /**
+     * Returns the Xtype string applying to the values described by
+     * this object.  The Xtype string is the 'extended type' information
+     * characterising the data type beyond the primitive data type.
+     * It is used within IVOA standards, and a number of standard
+     * values are defined within the
+     * <a href="http://www.ivoa.net/documents/DALI">DALI</a> standard.
+     *
+     * @return  the Xtype, or <code>null</code> if none is known
+     */
+    String getXtype();
+
     /**
      * Returns a description of the values described by this object.
      * It may contain a short or long textual description of the kind of
@@ -160,6 +173,16 @@ public interface ValueInfo {
      */
     boolean isNullable();
 
+    /**
+     * Returns a list of auxiliary metadata objects
+     * pertaining to this info.
+     * This is intended as a repository for metadata which is not
+     * otherwise made available in this interface.
+     *
+     * @return   a List of <tt>DescribedValue</tt> items
+     */
+    List<DescribedValue> getAuxData();
+
     /**
      * Returns an array of objects which may be able to convert from the
      * values described by this info to a particular target value domain.
@@ -198,4 +221,27 @@ public interface ValueInfo {
      */
     Object unformatString( String rep );
 
+    /**
+     * Gets an item of auxiliary metadata by its name.
+     *
+     * @param  name  the name of an auxiliary metadata item
+     * @return  a <tt>DescribedValue</tt> object representing the
+     *          named auxiliary metadata item for this column,
+     *          or <tt>null</tt> if none exists
+     */
+    default DescribedValue getAuxDatumByName( String name ) {
+        return Tables.getDescribedValueByName( getAuxData(), name );
+    }
+
+    /**
+     * Adds the given DescribedValue to the list of auxiliary metadata
+     * for this object.  If an item in the metadata list with the same
+     * name as the supplied value already exists, it is removed from the
+     * list.
+     *
+     * @param  dval  the new datum to add
+     */
+    default void setAuxDatum( DescribedValue dval ) {
+        Tables.setDescribedValue( getAuxData(), dval );
+    }
 }
