@@ -26,7 +26,10 @@ public class IpacTableWriter extends AbstractTextTableWriter {
      * Constructor.
      */
     public IpacTableWriter() {
-        super( true );
+        super( new String[] { "tbl", "ipac" }, true );
+        setMaxWidth( 1000 );
+        // The comments parameter may be many lines long
+        setMaximumParameterLength( 100_000 );
     }
 
     /**
@@ -37,6 +40,14 @@ public class IpacTableWriter extends AbstractTextTableWriter {
         return "IPAC";
     }
 
+    public boolean docIncludesExample() {
+        return true;
+    }
+
+    public String getXmlDescription() {
+        return readText( "IpacTableWriter.xml" );
+    }
+
     /**
      * Returns "text/plain".
      */
@@ -45,19 +56,6 @@ public class IpacTableWriter extends AbstractTextTableWriter {
         return "text/plain";
     }
 
-    /**
-     * Returns true for files with extension ".ipac" or ".tbl".
-     */
-    public boolean looksLikeFile( String location ) {
-        return location.endsWith( ".tbl" )
-            || location.endsWith( ".ipac" );
-    }
-
-    @Override
-    public int getMaxWidth() {
-        return 1000;
-    }
-
     @Override
     public int getMinNameWidth( ColumnInfo info ) {
         return new IpacHead( info ).name_.length();
@@ -154,14 +152,6 @@ public class IpacTableWriter extends AbstractTextTableWriter {
         }
     }
 
-    /**
-     * The comments parameter may be many lines long.
-     */
-    @Override
-    protected int getMaximumParameterLength() {
-        return 100000;
-    }
-
     /**
      * Truncate a string to avoid it being very long.
      *
