@@ -19,6 +19,7 @@ import uk.ac.starlink.table.TimeMapper;
  */
 public class RowEvaluator {
 
+    private boolean[] maybeBlank_;
     private boolean[] maybeBoolean_;
     private boolean[] maybeShort_;
     private boolean[] maybeInteger_;
@@ -54,6 +55,18 @@ public class RowEvaluator {
         "([+-]?)(Infinity|inf)", Pattern.CASE_INSENSITIVE
     );
 
+    /** Decoder for values that are all blank. */
+    private static Decoder BLANK_DECODER = new StringDecoder() {
+        private Pattern blankRegex_ = Pattern.compile( " *" );
+        public Object decode( String value ) {
+            return null;
+        }
+        public boolean isValid( String value ) {
+            return value == null
+                || blankRegex_.matcher( value ).matches();
+        }
+    };
+
     /** Decoder for booleans. */
     private static Decoder BOOLEAN_DECODER = new Decoder( Boolean.class ) {
         public Object decode( String value ) {
@@ -235,6 +248,7 @@ public class RowEvaluator {
 
         /* This data could be set up more compactly, indexing via type-specific
          * decoders rather than having a named array for each possible type. */
+        maybeBlank_ = makeFlagArray( true );
         maybeBoolean_ = makeFlagArray( true );
         maybeShort_ = makeFlagArray( true );
         maybeInteger_ = makeFlagArray( true );
@@ -271,87 +285,45 @@ public class RowEvaluator {
             int leng0 = cell0 == null ? 0 : cell0.length();
             String cell = cell0 == null ? "" : cell0.trim();
             int leng = cell.length();
-            if ( leng == 0 ) {
-                done = true;
-            }
             if ( leng0 > stringLength_[ icol ] ) {
                 stringLength_[ icol ] = leng0;
             }
-            if ( ! done && maybeBoolean_[ icol ] ) {
-                if ( BOOLEAN_DECODER.isValid( cell ) ) {
-                    done = true;
-                }
-                else {
-                    maybeBoolean_[ icol ] = false;
-                }
-            }
-            if ( ! done && maybeShort_[ icol ] ) {
-                if ( SHORT_DECODER.isValid( cell ) ) {
-                    done = true;
-                }
-                else {
-                    maybeShort_[ icol ] = false;
-                }
-            }
-            if ( ! done && maybeInteger_[ icol ] ) {
-                if ( INTEGER_DECODER.isValid( cell ) ) {
-                    done = true;
-                }
-                else {
-                    maybeInteger_[ icol ] = false;
-                }
-            }
-            if ( ! done && maybeLong_[ icol ] ) {
-                if ( LONG_DECODER.isValid( cell ) ) {
-                    done = true;
-                }
-                else {
-                    maybeLong_[ icol ] = false;
-                }
-            }
-            if ( ! done && maybeFloat_[ icol ] ) {
-                if ( FLOAT_DECODER.isValid( cell ) ) {
-                    done = true;
-                }
-                else {
-                    maybeFloat_[ icol ] = false;
-                }
-            }
-            if ( ! done && maybeDouble_[ icol ] ) {
-                if ( DOUBLE_DECODER.isValid( cell ) ) {
-                    done = true;
-                }
-                else {
-                    maybeDouble_[ icol ] = false;
-                }
-            }
-            if ( ! done && maybeDate_[ icol ] ) {
-                if ( DATE_DECODER.isValid( cell ) ) {
-                    done = true;
-                }
-                else {
-                    maybeDate_[ icol ] = false;
-                }
-            }
-            if ( ! done && maybeHms_[ icol ] ) {
-                if ( HMS_DECODER.isValid( cell ) ) {
-                    done = true;
-                }
-                else {
-                    maybeHms_[ icol ] = false;
-                }
-            }
-            if ( ! done && maybeDms_[ icol ] ) {
-                if ( DMS_DECODER.isValid( cell ) ) {
-                    done = true;
-                }
-                else {
-                    maybeDms_[ icol ] = false;
-                }
+            if ( leng > 0 ) {
+                updateColFlag( icol, cell, maybeBlank_, BLANK_DECODER );
+                updateColFlag( icol, cell, maybeBoolean_, BOOLEAN_DECODER );
+                updateColFlag( icol, cell, maybeShort_, SHORT_DECODER );
+                updateColFlag( icol, cell, maybeInteger_, INTEGER_DECODER );
+                updateColFlag( icol, cell, maybeLong_, LONG_DECODER );
+                updateColFlag( icol, cell, maybeFloat_, FLOAT_DECODER );
+                updateColFlag( icol, cell, maybeDouble_, DOUBLE_DECODER );
+                updateColFlag( icol, cell, maybeDate_, DATE_DECODER );
+                updateColFlag( icol, cell, maybeHms_, HMS_DECODER );
+                updateColFlag( icol, cell, maybeDms_, DMS_DECODER );
             }
         }
     }
 
+    /**
+     * Updates an element of a flags array based on compatibility of
+     * a cell value with a given decoder.
+     *
+     * @param  icol  index into colFlags array
+     * @param  cell  test cell value
+     * @param  colFlags   flags array
+     * @param  decoder   if cell is marked as invalid by decoder,
+     *                   then <code>colFlags[icol]</code> will be set false
+     */
+    private static void updateColFlag( int icol, String cell,
+                                       boolean[] colFlags, Decoder decoder ) {
+
+        /* Get the short circuiting right for efficiency; a failed validity
+         * test can throw an exception and so be expensive, so it's important
+         * that it's not done over and over again for a column. */
+        if ( colFlags[ icol ] && ! decoder.isValid( cell ) ) {
+            colFlags[ icol ] = false;
+        }
+    }
+
     /**
      * Returns information gleaned from previous <tt>submitRow</tt>
      * calls about the kind of data that appears to be in the columns.
@@ -364,7 +336,10 @@ public class RowEvaluator {
         for ( int icol = 0; icol < ncol_; icol++ ) {
             final Decoder decoder;
             String name = "col" + ( icol + 1 );
-            if ( maybeBoolean_[ icol ] ) {
+            if ( maybeBlank_[ icol ] ) {
+                decoder = BLANK_DECODER;
+            }
+            else if ( maybeBoolean_[ icol ] ) {
                 decoder = BOOLEAN_DECODER;
             }
             else if ( maybeShort_[ icol ] ) {
